"""
AHT10 Hőmérséklet- és Páratartalom-Érzékelő Program

Ez a CircuitPython program kiolvassa az AHT10 szenzorból a
hőmérséklet- és a páratartalom-értékeket, majd kiírja a standard kimenetre.
 
A program:
- Inicializálja az I2C kommunikációt.
- Elvégzi az érzékelő kalibrálását.
- Időszakosan kiolvassa az érzékelő adatait.
- Kiírja a mért páratartalmat (%) és a hőmérsékletet (°C) a terminálra.

Hardver követelmények:
  ESP32-C3 mikrovezérlő
  AHT10 breakout kártya (hőmérséklet- és páratartalom-érzékelő)

Bekötési vázlat:
==========================
 AHT10  ESP32-C3 Supermini
 SDA -- GPIO8
 SCL -- GPIO9
 GND -- GND
 VCC -- 3.3V

Tesztelve a CircuitPython 9.2.1 firmware-rel, ESP32-C3 kártyán
"""


import board
import busio
import time

# I2C inicializálása
i2c = busio.I2C(board.SCL, board.SDA)

# Kalibrálás parancs
calibration_command = bytes([0xE1, 0x08, 0x00])
while not i2c.try_lock():
    pass

try:
    i2c.writeto(0x38, calibration_command)  # 0x38 az AHT10 alapértelmezett címe
    time.sleep(0.02)  # Várakozás 20 ms (kalibrálás befejezése)
finally:
    i2c.unlock()
    
while True:
    data = bytearray(6)  # 6 bájt adatot olvasunk be
    while not i2c.try_lock():
        pass
    
    try: 
        i2c.writeto(0x38, bytes([0xAC, 0x33, 0x00]))
        time.sleep(0.02)
        i2c.readfrom_into(0x38, data)
    finally:
        i2c.unlock()
        
    print("--------------------------") 
    # Páratartalom számítása
    humidity = (data[1] << 12) | (data[2] << 4) | (data[3] >> 4)
    humidity = humidity * 100 / 0x100000

    # Hőmérséklet számítása
    temperature = ((data[3] & 0x0F) << 16) | (data[4] << 8) | data[5]
    temperature = temperature * 200 / 1048576 - 50

    # Eredmények kiíratása
    print(f"Humidity: {humidity:.1f}%")
    print(f"Temperature: {temperature:.1f} C")

    time.sleep(2)  # 2 másodpercenként frissít
    
