"""
AHT10 Hőmérséklet- és Páratartalom-Érzékelő Program 

Ez a program az Adafruit CircuitPython `ahtx0` könyvtárára támaszkodva olvassa ki az 
AHT10 szenzorból a hőmérséklet- és páratartalom-értékeket. 
Az Adafruit AHTx0 könyvtár alkalmazása leegyszerűsíti az érzékelő inicializálását és 
kiolvasását.

A program:
- Inicializálja az I2C kommunikációt.
- Használja az Adafruit AHTx0 könyvtárat az adatok egyszerű kiolvasásához.
- Időszakosan kiolvassa az érzékelő adatait.
- Kiírja a mért páratartalmat (%) és a hőmérsékletet (°C) a terminálra.

Fontos lépések:
1. Az Adafruit `ahtx0.mpy` könyvtár fájlját másold be az ESP32-S3 Supermini `/lib` mappájába.
   - A könyvtár letölthető az Adafruit CircuitPython Library Bundle-ből: 
     https://circuitpython.org/libraries
2. A program futtatásához győződj meg róla, hogy az AHT10 megfelelően csatlakoztatva van, 
   és az I2C cím megfelel az alapértelmezett 0x38 címnek.

Hardver követelmények:
1. ESP32-S3 Supermini mikrovezérlő
2. AHT10 breakout kártya (hőmérséklet- és páratartalom-érzékelő)

Bekötési vázlat:
==========================
 AHT10  ESP32-C3 Supermini
 SDA -- GPIO8
 SCL -- GPIO9
 GND -- GND
 VCC -- 3.3V

Tesztelve a CircuitPython 9.2.1 firmware-rel, ESP32-C3 kártyán
"""

import time
import board
import adafruit_ahtx0

# Create sensor object, communicating over the board's default I2C bus
i2c = board.I2C()           # uses board.SCL and board.SDA
sensor = adafruit_ahtx0.AHTx0(i2c)    

while True:
    print("Temperature: %0.1f C" % sensor.temperature)
    print("Humidity: %0.1f %%" % sensor.relative_humidity)
    print("----------------------")
    time.sleep(2)
